"""
This is the template for the computation problem of computing a Groebner basis of an ideal
generated by a finite set of polynomials with coefficients in a finite field (commutative). It creates
code for the computer algebra system Maple.

@author: Albert Heinle
@contact: albert.heinle@rwth-aachen.de
"""

#--------------------------------------------------
#---------------The template-----------------------
#--------------------------------------------------

def generateCode(vars, basis, characteristic):
    """
    The main function generating the Maple code for the computation of
    the Groebner basis given the input variables.

    @param           vars: A list of variables used in the ModPS-System
    @type            vars: list
    @param          basis: The polynomials forming a basis of the ModPS-System. This input will not be checked whether
                           there are polynomials using variables not in the list of variables.
    @type           basis: list
    @param characteristic: The characteristic of the field where the coefficients are taken from.
    @type  characteristic: int
    """
    result = "\
with(Groebner):\n\
Ideal := {%s} mod %i:\n\
ordering := grlex(%s):\n\
Basis(Ideal, ordering):\n\
print(B);\n\
quit;\
" % (",".join(basis),
     characteristic,
     ",".join(vars))
    return result

#--------------------------------------------------
#----------------Help Functions--------------------
#--------------------------------------------------
