"""
This is the template for the computation problem of computing a Groebner basis of an ideal
generated by a finite set of polynomials with integer coefficients (commutative). It creates
code for the computer algebra system Singular.

@author: Albert Heinle
@contact: albert.heinle@rwth-aachen.de
"""

#--------------------------------------------------
#---------------The template-----------------------
#--------------------------------------------------

def generateCode(vars, basis):
    """
    The main function generating the Singular code for the computation of
    the Groebner basis given the input variables.

    @param         vars: A list of variables used in the INTPS-System
    @type          vars: list
    @param        basis: The polynomials forming a basis of the INTPS-System. This input will not be checked whether
                         there are polynomials using variables not in the list of variables.
    @type         basis: list
    """
    result = "\
ring R = 0,(%s),lp;\n\
ideal I = %s;\n\
ideal J = std(I);\n\
print(J);\n\
$\
" % (",".join(vars),",\n".join(basis))
    return result

#--------------------------------------------------
#----------------Help Functions--------------------
#--------------------------------------------------
